@@ -200,7 +200,7 @@ class Kitchen(arcade.Window):
                     r.kill()
                     self.GAME_PAUSE = True
                     self.music.stop()
-                    self.bomb.play()
+                    self.bomb.play(MUSIC_VOLUME)
                 else:
                     self.score += score
                     self.kills.append(r)
